#line 1 "/build/libiio/src/build/iiod/lexer.c"

#line 3 "/build/libiio/src/build/iiod/lexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yyget_lval
#define yyget_lval_ALREADY_DEFINED
#else
#define yyget_lval yyget_lval
#endif

#ifdef yyset_lval
#define yyset_lval_ALREADY_DEFINED
#else
#define yyset_lval yyset_lval
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

#define yywrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 28
#define YY_END_OF_BUFFER 29
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[287] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   29,   27,   25,   26,   27,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   16,   16,   16,   16,
       16,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   21,   21,   21,   21,   21,   22,   22,   22,   22,
       22,   25,   26,    0,   24,    0,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,

       24,   24,   24,   24,   24,   24,   16,    0,   16,   16,
       16,   16,   24,   24,   24,   24,   24,   24,   24,   24,
       21,    0,   21,   21,   21,   21,   22,    0,   22,   22,
       22,   22,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   15,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   15,   24,   24,   24,
       24,   16,   16,   16,   24,   24,   24,   24,   24,   24,
       24,   24,   21,   21,   21,   22,   22,   22,   24,   24,
        4,   24,    5,    7,   24,    9,   24,   24,   24,   24,
       24,   24,   24,   24,   24,    9,   24,   24,   24,   24,

       24,   16,   16,   24,   24,   24,   24,   24,   24,   24,
       24,   21,   21,   22,   22,    8,   24,   24,    2,   24,
       24,   24,   24,   12,   24,   24,   24,   24,   24,   24,
       24,   12,   24,   16,   16,   24,   18,   20,   24,   24,
       24,   21,   21,   22,   22,   23,   24,   24,   24,   24,
       24,   24,    3,   24,   24,   24,   24,   24,   24,   16,
       19,   19,   21,   22,   14,   10,   13,    6,    1,   24,
       24,   24,   24,   11,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   17,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    5,    6,    7,    1,    8,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    9,    1,    1,
        1,    1,    1,    1,   10,   11,   12,   13,   14,   15,
       16,   17,   18,   19,   19,   20,   21,   22,   23,   24,
       25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
        1,    1,    1,    1,   35,    1,   36,   37,   38,   39,

       40,   41,   42,   43,   44,   19,   19,   45,   46,   47,
       48,   49,   50,   51,   52,   53,   54,   55,   56,   57,
       58,   59,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[60] =
    {   0,
        1,    1,    1,    1,    2,    3,    3,    3,    1,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3
    } ;

static const flex_int16_t yy_base[299] =
    {   0,
        0,    0,   59,  103,  147,  195,  243,  287,   77,  261,
      331,  375,  102, 2356,   70, 2356,   98,    0,   78,  221,
      129,  262,  306,  122,  137,  182,  310,  350,  354,  385,
      389,  170,  395,  399,  420,  430,  436,  440,  444,  456,
      461,  476,  480,  492,  498,  512,    0,  230,  523,  529,
      533,  537,  545,  568,  578,  583,  587,  591,  599,  603,
      609,    0,  622,  646,  653,  659,    0,  663,  667,  677,
      684,   73, 2356,   96,    0,    0,  699,  708,  715,  731,
      739,  748,  755,  770,  774,  779,  765,  789,  796,  810,
      827,  831,  835,  841,  849,  853,  875,  884,  898,  906,

      910,  920,  924,  929,  946,  960,    0,    0,  969,  977,
      986,  991,  995, 1008, 1001, 1026, 1039, 1044, 1050, 1057,
        0,    0, 1061, 1065, 1081, 1096,    0,    0, 1100, 1106,
     1115, 1119, 1131, 1140, 1156, 1164, 1171, 1175, 1180, 1206,
     1211, 1215, 1221, 1225, 1231, 1256, 1262, 1270, 1274, 1278,
     1287, 1293, 1282, 1313, 1318, 1327, 1332, 1337, 1344, 1349,
     1368, 1375, 1381, 1385, 1392, 1416, 1423, 1429, 1433, 1441,
     1449, 1455, 1465, 1472, 1503, 1481, 1486, 1517, 1522, 1527,
     1534, 1541, 1548, 1553, 1558, 1566, 1573, 1584, 1597, 1604,
     1615, 1589, 1620, 1628, 1635, 1639, 1646, 1651, 1660, 1677,

     1684, 1695, 1700, 1715, 1720, 1732, 1740, 1746, 1756, 1765,
     1771, 1777, 1782, 1796, 1802, 1814, 1822, 1833, 1837, 1847,
     1853, 1857, 1872, 1891, 1903, 1898, 1907, 1911, 1915, 1922,
     1947, 1955, 1961, 1965, 1973, 1978, 2010, 2014, 2018, 2022,
     2026, 2030, 2061, 2069, 2077, 2081, 2085, 2102, 2116, 2120,
     2128, 2133, 2137, 2151, 2159, 2168, 2172, 2176, 2182, 2191,
     2207, 2213, 2222, 2232, 2238, 2244, 2248, 2253, 2263, 2269,
     2284, 2288, 2294, 2300,   86,   58,   70,   44,   62,   35,
       65,   35,   53,   27,    0, 2356, 2335, 2338, 2341, 2344,
       76, 2346,   75, 2348,   67, 2350,   66, 2352

    } ;

static const flex_int16_t yy_def[299] =
    {   0,
      286,    1,  287,  287,  288,  288,  289,  289,    6,    6,
      290,  290,  286,  286,  286,  286,  286,  291,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  292,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  292,  292,  292,
      292,  292,  292,  292,  292,  292,  293,  294,  294,  294,
      294,  292,  292,  292,  292,  292,  292,  292,  292,  292,
      292,  295,  296,  296,  296,  296,  297,  298,  298,  298,
      298,  286,  286,  286,  291,  291,  292,  292,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  292,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  292,  292,  292,

      292,  292,  292,  292,  292,  292,  293,  293,  294,  294,
      294,  294,  292,  292,  292,  292,  292,  292,  292,  292,
      295,  295,  296,  296,  296,  296,  297,  297,  298,  298,
      298,  298,  292,  292,  292,  292,  292,  292,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  292,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  292,  292,  292,
      292,  294,  294,  294,  292,  292,  292,  292,  292,  292,
      292,  292,  296,  296,  296,  298,  298,  298,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  292,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  292,  292,  292,

      292,  294,  294,  292,  292,  292,  292,  292,  292,  292,
      292,  296,  296,  298,  298,  292,  292,  292,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  292,  292,  292,
      292,  292,  292,  294,  294,  292,  292,  292,  292,  292,
      292,  296,  296,  298,  298,  292,  292,  292,  292,  292,
      292,  292,  292,  292,  292,  292,  292,  292,  292,  294,
      292,  292,  296,  298,  292,  292,  292,  292,  292,  292,
      292,  292,  292,  292,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,    0,  286,  286,  286,  286,
      286,  286,  286,  286,  286,  286,  286,  286

    } ;

static const flex_int16_t yy_nxt[2416] =
    {   0,
       14,   15,   16,   17,   14,   18,   18,   18,   14,   19,
       19,   20,   19,   21,   19,   22,   23,   19,   19,   19,
       19,   19,   24,   25,   26,   27,   28,   29,   19,   30,
       31,   19,   19,   32,   18,   19,   19,   33,   19,   34,
       19,   35,   36,   37,   19,   19,   19,   38,   39,   40,
       41,   42,   43,   19,   44,   45,   19,   19,   46,   14,
       15,   16,   17,   14,   47,   47,   47,   14,  127,  121,
       49,   72,   73,   74,   72,   73,   74,  107,   75,  285,
      285,  284,   76,   75,   75,   75,  283,   19,  282,   19,
      281,  280,  279,   47,   19,  278,   50,  277,   73,   19,

       73,  286,   51,   14,   15,   16,   17,   14,   47,   47,
       47,   14,   75,   19,   49,   19,  286,  286,  286,  286,
       37,  286,  286,  286,   19,  286,   76,   75,   75,   75,
      286,  286,  286,   76,   75,   75,   75,   47,  286,  286,
       50,   76,   75,   75,   75,   83,   51,   14,   15,   16,
       17,   14,   18,   18,   18,   14,   75,   52,   53,   54,
       80,  286,   84,   75,   55,  286,  286,  286,  286,   56,
      286,   75,  286,  286,   76,   75,   75,   75,  286,  286,
      286,   18,  286,   57,   58,   59,   76,   75,   75,   75,
       60,  286,  286,   91,   61,   14,   15,   16,   17,   14,

       18,   18,   18,   14,   75,   52,   53,   54,  286,  286,
       85,  286,   55,  286,  286,  286,   75,   56,  286,  286,
      286,  286,  286,  286,  286,   76,   75,   75,   75,   18,
      286,   57,   58,   59,  108,  107,  107,  107,   60,  286,
       78,  286,   61,   14,   15,   16,   17,   14,   62,   62,
       62,   14,  286,   79,   64,   75,  286,  286,  286,  286,
      286,  286,  286,  286,  107,  286,   76,   75,   75,   75,
      286,   19,  286,   19,  286,   81,  286,   62,   19,  286,
       65,  286,  286,   19,  286,  286,   66,   14,   15,   16,
       17,   14,   62,   62,   62,   14,   75,   19,   64,   19,

      286,  286,  286,  286,   37,  286,  286,  286,   19,  286,
       76,   75,   75,   75,   76,   75,   75,   75,  286,   82,
      286,   62,  286,   86,   65,  286,  286,  286,  286,  286,
       66,   14,   15,   16,   17,   14,   67,   67,   67,   14,
       75,  286,   69,  286,   75,  286,  286,  286,  286,  286,
      286,  286,  286,  286,   76,   75,   75,   75,   76,   75,
       75,   75,  286,   87,  286,   67,  286,  286,   70,  286,
      286,   88,  286,  286,   71,   14,   15,   16,   17,   14,
       67,   67,   67,   14,   75,  286,   69,  286,   75,   76,
       75,   75,   75,   76,   75,   75,   75,  286,   89,   76,

       75,   75,   75,   76,   75,   75,   75,  286,  286,   67,
      286,  286,   70,  286,   90,  286,  286,  286,   71,   75,
      286,  286,  286,   75,   76,   75,   75,   75,  286,   75,
      286,  286,  286,   75,   76,   75,   75,   75,  286,   92,
       76,   75,   75,   75,   76,   75,   75,   75,   76,   75,
       75,   75,   93,  286,   75,   94,  286,  286,  286,   95,
       76,   75,   75,   75,   75,   76,   75,   75,   75,   96,
       75,  286,  286,  286,   75,  286,  286,  286,   75,   97,
       76,   75,   75,   75,   76,   75,   75,   75,   98,  286,
       75,  286,  286,  286,   99,   75,   76,   75,   75,   75,

      101,  286,   76,   75,   75,   75,  286,  286,  286,  100,
       75,  286,  286,  286,   75,  102,   76,   75,   75,   75,
      286,  286,  286,  103,  286,  286,   75,  108,  107,  107,
      107,  104,   75,  108,  107,  107,  107,  108,  107,  107,
      107,   76,   75,   75,   75,  286,   75,  286,  105,   76,
       75,   75,   75,  286,  286,  110,  286,  107,  286,  286,
      106,  286,  286,  107,  286,  113,  286,  107,  286,  286,
      286,   75,   76,   75,   75,   75,  112,   79,  286,   75,
      286,  114,   76,   75,   75,   75,  111,   76,   75,   75,
       75,   76,   75,   75,   75,   76,   75,   75,   75,  115,

      286,  286,   75,   76,   75,   75,   75,   76,   75,   75,
       75,  116,   75,   76,   75,   75,   75,   75,  286,  286,
      286,   75,  286,  286,  286,   75,  122,  121,  121,  121,
      286,  286,  286,   75,  286,  286,  286,   75,  118,  286,
      117,  286,  286,   75,  286,  286,   97,  286,   93,  119,
      122,  121,  121,  121,  286,  286,  121,  122,  121,  121,
      121,  286,  120,  122,  121,  121,  121,  128,  127,  127,
      127,  128,  127,  127,  127,  286,  286,  286,  124,  286,
      121,  128,  127,  127,  127,  286,  286,  121,  128,  127,
      127,  127,  286,  121,  286,  286,  286,  127,  286,  130,

      286,  127,  126,   76,   75,   75,   75,  286,  286,  286,
      125,  127,   76,   75,   75,   75,  286,  286,  127,   76,
       75,   75,   75,  286,  286,  286,  134,  132,  286,  286,
      133,  286,  286,   75,  131,   76,   75,   75,   75,  286,
      286,  286,   75,   76,   75,   75,   75,  286,  135,   75,
      286,  286,   76,   75,   75,   75,  286,  286,  286,   76,
       75,   75,   75,  286,  286,   75,  136,  137,  138,   76,
       75,   75,   75,   75,   76,   75,   75,   75,   76,   75,
       75,   75,   75,   76,   75,   75,   75,  139,  141,   75,
      286,  140,  142,   76,   75,   75,   75,  286,  286,   75,

       76,   75,   75,   75,   75,  286,  286,  286,   75,  143,
      286,  286,  286,   75,   76,   75,   75,   75,  286,  286,
      286,  144,  286,   75,  286,  286,  286,  145,  286,  286,
       75,   76,   75,   75,   75,   76,   75,   75,   75,   76,
       75,   75,   75,  286,   75,   76,   75,   75,   75,  286,
      286,  286,  146,   76,   75,   75,   75,   76,   75,   75,
       75,   75,  286,  286,  286,   75,  286,  286,  286,   75,
      286,  286,  148,  286,  286,   75,  286,  286,  147,   76,
       75,   75,   75,   75,  149,  286,  286,   75,   76,   75,
       75,   75,  286,  286,  286,  286,  286,  151,  286,  286,

      286,  150,   76,   75,   75,   75,  286,  286,  286,   75,
       76,   75,   75,   75,   76,   75,   75,   75,   75,  286,
      286,  286,  152,  153,   76,   75,   75,   75,   76,   75,
       75,   75,   75,   76,   75,   75,   75,  286,  286,  286,
       75,  154,  286,  286,   75,  156,  286,  286,  286,  155,
       76,   75,   75,   75,   75,  286,  286,  286,   75,  286,
      286,  286,  286,   75,   76,   75,   75,   75,  286,  158,
      286,  286,  157,  108,  107,  107,  107,  286,  286,  159,
       75,  108,  107,  107,  107,  286,  286,  286,  162,  160,
      108,  107,  107,  107,   75,  108,  107,  107,  107,   76,

       75,   75,   75,  107,  286,   76,   75,   75,   75,  165,
      161,  107,   76,   75,   75,   75,  286,  286,  166,  286,
      107,  286,  286,  163,  167,  107,  286,  286,  286,   75,
       76,   75,   75,   75,  286,   75,  286,  286,  164,  286,
      286,  286,   75,   76,   75,   75,   75,  286,   76,   75,
       75,   75,  286,  168,   76,   75,   75,   75,  286,  286,
       75,   76,   75,   75,   75,  122,  121,  121,  121,  122,
      121,  121,  121,   75,  286,  286,  173,  286,   75,  169,
      170,  286,  286,  286,   75,  122,  121,  121,  121,  286,
      286,   75,  286,  286,  286,  121,  286,  286,  171,  121,

      122,  121,  121,  121,  128,  127,  127,  127,  286,  172,
      128,  127,  127,  127,  286,  121,  286,  176,  174,  128,
      127,  127,  127,  128,  127,  127,  127,  286,  286,  286,
      121,  286,  286,  286,  127,   76,   75,   75,   75,  286,
      127,  286,  286,  175,   76,   75,   75,   75,  286,  127,
      286,  286,  177,  127,  286,  286,  286,  179,  286,  180,
       76,   75,   75,   75,  286,   75,  178,  286,   76,   75,
       75,   75,  286,  286,   75,   76,   75,   75,   75,   76,
       75,   75,   75,  181,   76,   75,   75,   75,  286,  286,
       75,  182,  286,  286,  183,  286,  184,  286,   75,  286,

      286,  185,  286,  286,  286,   75,  286,  286,  286,   75,
       76,   75,   75,   75,   75,   76,   75,   75,   75,   76,
       75,   75,   75,  186,  286,   76,   75,   75,   75,   76,
       75,   75,   75,  181,  188,   76,   75,   75,   75,  286,
       75,  286,  187,  286,  286,   75,  286,  286,  286,   75,
      286,  189,  286,  286,  286,   75,  286,  286,  190,   75,
       76,   75,   75,   75,  286,   75,   76,   75,   75,   75,
      286,  286,  286,  191,   76,   75,   75,   75,   76,   75,
       75,   75,   76,   75,   75,   75,   76,   75,   75,   75,
       75,   76,   75,   75,   75,  286,   75,   76,   75,   75,

       75,   76,  286,  286,   75,  286,  286,  286,   75,  286,
      286,  286,   75,  192,  193,  286,   75,   76,   75,   75,
       75,   75,   76,   75,   75,   75,  181,   75,  184,  286,
      194,   76,   75,   75,   75,  183,   76,   75,   75,   75,
      286,   76,   75,   75,   75,  286,  286,   75,   76,   75,
       75,   75,   75,   76,   75,   75,   75,  286,  286,  195,
      286,   75,  286,  286,  286,  196,   75,  286,  286,  286,
      181,   75,   76,   75,   75,   75,  198,  286,   75,  108,
      107,  107,  107,   75,  197,  108,  107,  107,  107,  108,
      107,  107,  107,  108,  202,  199,   76,   75,   75,   75,

      286,  200,   75,  286,  286,  286,  204,  286,  286,  107,
      286,  201,  286,  286,  286,  107,  286,  286,  286,  107,
       76,   75,   75,   75,  286,  203,   75,   76,   75,   75,
       75,  286,  286,   76,   75,   75,   75,   76,   75,   75,
       75,  286,  286,  286,  205,   76,   75,   75,   75,  286,
       75,  206,  207,   76,   75,   75,   75,   75,  286,   76,
       75,   75,   75,   75,  286,  286,  286,   75,  286,  122,
      121,  121,  121,  208,  286,   75,  122,  121,  121,  121,
      286,  286,  286,   75,  212,  128,  127,  127,  127,   75,
      128,  127,  127,  127,  209,  286,  286,  286,  286,  121,

      214,  286,  210,  211,  286,  286,  121,  122,  121,  121,
      121,  122,  286,  286,  286,  127,  213,  286,  286,  286,
      127,  128,  127,  127,  127,  128,   76,   75,   75,   75,
      215,   76,   75,   75,   75,  216,  286,  121,   76,   75,
       75,   75,  286,  286,  217,   76,   75,   75,   75,  286,
      286,  127,   76,   75,   75,   75,   75,   76,   75,   75,
       75,   75,   76,   75,   75,   75,  218,  286,   75,  286,
       76,   75,   75,   75,  286,   75,  220,   76,   75,   75,
       75,  286,   75,  286,  286,  219,  286,   75,   76,   75,
       75,   75,   75,   76,   75,   75,   75,  286,  221,  286,

       75,   76,   75,   75,   75,  286,  222,   75,   76,   75,
       75,   75,  286,  286,  223,  286,  286,  224,   75,   76,
       75,   75,   75,   75,   76,   75,   75,   75,  216,  286,
      286,   75,   76,   75,   75,   75,  225,  286,   75,   76,
       75,   75,   75,   76,   75,   75,   75,  286,  286,   75,
       76,   75,   75,   75,   75,   76,   75,   75,   75,  286,
      286,  286,   75,  226,   76,   75,   75,   75,  286,   75,
      286,  286,  286,   75,  286,  228,  286,  286,  227,  286,
       75,   76,   75,   75,   75,   75,  286,  219,   76,   75,
       75,   75,  286,  286,   75,  286,  229,  286,  230,  108,

      107,  107,  107,  231,  108,  107,  107,  107,  286,  286,
      286,   75,  234,  286,  286,  286,  232,  286,   75,   76,
       75,   75,   75,  286,   76,   75,   75,   75,  236,  107,
      233,  286,  286,  286,  107,  237,   76,   75,   75,   75,
      286,  286,  286,  235,   76,   75,   75,   75,  286,   75,
       76,   75,   75,   75,   75,  286,  286,  286,  286,  238,
       76,   75,   75,   75,  286,  286,   75,  286,  239,   76,
       75,   75,   75,  286,   75,   76,   75,   75,   75,  286,
       75,  122,  121,  121,  121,  240,  122,  121,  121,  121,
       75,  286,  286,  286,  242,  286,  286,  237,  286,   75,

      128,  127,  127,  127,  286,   75,  128,  127,  127,  127,
      286,  121,  286,  244,  286,  286,  121,  238,   76,   75,
       75,   75,  286,  286,  241,  243,   76,   75,   75,   75,
      127,  286,  286,  246,  286,  286,  127,   76,   75,   75,
       75,   76,   75,   75,   75,  245,  286,  286,   75,  286,
      247,   76,   75,   75,   75,  286,   75,   76,   75,   75,
       75,   76,   75,   75,   75,  286,  286,   75,  286,  286,
      249,   75,  286,  286,  286,  248,   76,   75,   75,   75,
      286,   75,  286,  286,  286,  250,  286,   75,  286,  286,
      286,   75,  286,  286,  251,   76,   75,   75,   75,  286,

      286,  252,   76,   75,   75,   75,   75,   76,   75,   75,
       75,   76,   75,   75,   75,   76,   75,   75,   75,   76,
       75,   75,   75,  286,  286,   75,   76,   75,   75,   75,
      253,  286,   75,  286,  286,  246,  286,   75,  286,  286,
      286,   75,  286,  286,  286,   75,  286,  286,  286,   75,
      254,   76,   75,   75,   75,  286,   75,  286,  256,   76,
       75,   75,   75,  286,  255,   76,   75,   75,   75,  108,
      107,  107,  107,  286,  286,  257,  260,  108,  107,  107,
      107,   75,   76,   75,   75,   75,  286,  286,  286,   75,
      286,  259,  286,  286,  258,   75,  286,  286,  286,  107,

      286,  286,  286,  261,  286,  286,  286,  107,  286,  286,
      260,  286,   75,  253,   76,   75,   75,   75,   76,   75,
       75,   75,   76,   75,   75,   75,   76,   75,   75,   75,
       76,   75,   75,   75,  122,  121,  121,  121,  286,  286,
      286,  263,  286,  286,   75,  238,  286,  286,   75,  286,
      286,  286,   75,  286,  286,  286,   75,  286,  286,  286,
       75,  286,  286,  286,  121,  122,  121,  121,  121,  286,
      286,  286,  262,  128,  127,  127,  127,  286,  238,  286,
      264,  128,  127,  127,  127,   76,   75,   75,   75,   76,
       75,   75,   75,  286,  286,  121,  286,  286,  263,  286,

      265,  286,  286,  127,  286,  286,   76,   75,   75,   75,
      286,  127,  286,  286,  264,   75,  266,  286,  286,   75,
       76,   75,   75,   75,   76,   75,   75,   75,  286,  286,
      286,  267,   76,   75,   75,   75,   75,   76,   75,   75,
       75,   76,   75,   75,   75,  286,  286,  268,  286,  269,
       75,  286,  286,  286,   75,   76,   75,   75,   75,  286,
      286,  270,   75,   76,   75,   75,   75,   75,  286,  286,
      286,   75,   76,   75,   75,   75,   76,   75,   75,   75,
       76,   75,   75,   75,  286,   75,   76,   75,   75,   75,
      286,  286,  265,   75,  286,  108,  107,  107,  107,  266,

      286,  286,   75,  286,  286,  286,   75,  286,  286,  267,
       75,   76,   75,   75,   75,  286,   75,   76,   75,   75,
       75,  286,  269,  286,  268,  107,  122,  121,  121,  121,
      286,  286,  286,  272,  286,  271,  128,  127,  127,  127,
      286,   75,   76,   75,   75,   75,  286,   75,   76,   75,
       75,   75,   76,   75,   75,   75,  121,   76,   75,   75,
       75,  286,  286,  286,  273,  286,  127,   76,   75,   75,
       75,  286,   75,   76,   75,   75,   75,  286,   75,  286,
      286,  286,   75,  274,  286,  286,  286,   75,   76,   75,
       75,   75,   76,   75,   75,   75,  286,   75,   76,   75,

       75,   75,  286,   75,   76,   75,   75,   75,  286,  286,
      286,  286,  286,  286,  286,  286,  286,  286,   75,  286,
      286,  286,  275,  286,  274,  286,  286,  286,  276,  286,
      286,  286,  286,  286,   75,   48,   48,   48,   19,   19,
       19,   63,   63,   63,   68,   68,   68,   77,   77,  109,
      109,  123,  123,  129,  129,   13,  286,  286,  286,  286,
      286,  286,  286,  286,  286,  286,  286,  286,  286,  286,
      286,  286,  286,  286,  286,  286,  286,  286,  286,  286,
      286,  286,  286,  286,  286,  286,  286,  286,  286,  286,
      286,  286,  286,  286,  286,  286,  286,  286,  286,  286,

      286,  286,  286,  286,  286,  286,  286,  286,  286,  286,
      286,  286,  286,  286,  286
    } ;

static const flex_int16_t yy_chk[2416] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    3,
        3,    3,    3,    3,    3,    3,    3,    3,  297,  295,
        3,   15,   15,   15,   72,   72,   72,  293,  291,  284,
      283,  282,   19,   19,   19,   19,  281,    9,  280,    9,
      279,  278,  277,    3,    9,  276,    3,  275,   74,    9,

       17,   13,    3,    4,    4,    4,    4,    4,    4,    4,
        4,    4,   19,    9,    4,    9,    0,    0,    0,    0,
        9,    0,    0,    0,    9,    0,   24,   24,   24,   24,
        0,    0,    0,   21,   21,   21,   21,    4,    0,    0,
        4,   25,   25,   25,   25,   24,    4,    5,    5,    5,
        5,    5,    5,    5,    5,    5,   24,    5,    5,    5,
       21,    0,   25,   21,    5,    0,    0,    0,    0,    5,
        0,   25,    0,    0,   32,   32,   32,   32,    0,    0,
        0,    5,    0,    5,    5,    5,   26,   26,   26,   26,
        5,    0,    0,   32,    5,    6,    6,    6,    6,    6,

        6,    6,    6,    6,   32,    6,    6,    6,    0,    0,
       26,    0,    6,    0,    0,    0,   26,    6,    0,    0,
        0,    0,    0,    0,    0,   20,   20,   20,   20,    6,
        0,    6,    6,    6,   48,   48,   48,   48,    6,    0,
       20,    0,    6,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    0,   20,    7,   20,    0,    0,    0,    0,
        0,    0,    0,    0,   48,    0,   22,   22,   22,   22,
        0,   10,    0,   10,    0,   22,    0,    7,   10,    0,
        7,    0,    0,   10,    0,    0,    7,    8,    8,    8,
        8,    8,    8,    8,    8,    8,   22,   10,    8,   10,

        0,    0,    0,    0,   10,    0,    0,    0,   10,    0,
       23,   23,   23,   23,   27,   27,   27,   27,    0,   23,
        0,    8,    0,   27,    8,    0,    0,    0,    0,    0,
        8,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       23,    0,   11,    0,   27,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   28,   28,   28,   28,   29,   29,
       29,   29,    0,   28,    0,   11,    0,    0,   11,    0,
        0,   29,    0,    0,   11,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   28,    0,   12,    0,   29,   30,
       30,   30,   30,   31,   31,   31,   31,    0,   30,   33,

       33,   33,   33,   34,   34,   34,   34,    0,    0,   12,
        0,    0,   12,    0,   31,    0,    0,    0,   12,   30,
        0,    0,    0,   31,   35,   35,   35,   35,    0,   33,
        0,    0,    0,   34,   36,   36,   36,   36,    0,   33,
       37,   37,   37,   37,   38,   38,   38,   38,   39,   39,
       39,   39,   33,    0,   35,   34,    0,    0,    0,   35,
       40,   40,   40,   40,   36,   41,   41,   41,   41,   36,
       37,    0,    0,    0,   38,    0,    0,    0,   39,   37,
       42,   42,   42,   42,   43,   43,   43,   43,   38,    0,
       40,    0,    0,    0,   39,   41,   44,   44,   44,   44,

       41,    0,   45,   45,   45,   45,    0,    0,    0,   40,
       42,    0,    0,    0,   43,   42,   46,   46,   46,   46,
        0,    0,    0,   43,    0,    0,   44,   49,   49,   49,
       49,   44,   45,   50,   50,   50,   50,   51,   51,   51,
       51,   52,   52,   52,   52,    0,   46,    0,   45,   53,
       53,   53,   53,    0,    0,   49,    0,   49,    0,    0,
       46,    0,    0,   50,    0,   52,    0,   51,    0,    0,
        0,   52,   54,   54,   54,   54,   51,   53,    0,   53,
        0,   54,   55,   55,   55,   55,   50,   56,   56,   56,
       56,   57,   57,   57,   57,   58,   58,   58,   58,   55,

        0,    0,   54,   59,   59,   59,   59,   60,   60,   60,
       60,   56,   55,   61,   61,   61,   61,   56,    0,    0,
        0,   57,    0,    0,    0,   58,   63,   63,   63,   63,
        0,    0,    0,   59,    0,    0,    0,   60,   59,    0,
       57,    0,    0,   61,    0,    0,   60,    0,   58,   60,
       64,   64,   64,   64,    0,    0,   63,   65,   65,   65,
       65,    0,   61,   66,   66,   66,   66,   68,   68,   68,
       68,   69,   69,   69,   69,    0,    0,    0,   64,    0,
       64,   70,   70,   70,   70,    0,    0,   65,   71,   71,
       71,   71,    0,   66,    0,    0,    0,   68,    0,   69,

        0,   69,   66,   77,   77,   77,   77,    0,    0,    0,
       65,   70,   78,   78,   78,   78,    0,    0,   71,   79,
       79,   79,   79,    0,    0,    0,   79,   71,    0,    0,
       78,    0,    0,   77,   70,   80,   80,   80,   80,    0,
        0,    0,   78,   81,   81,   81,   81,    0,   80,   79,
        0,    0,   82,   82,   82,   82,    0,    0,    0,   83,
       83,   83,   83,    0,    0,   80,   81,   82,   83,   87,
       87,   87,   87,   81,   84,   84,   84,   84,   85,   85,
       85,   85,   82,   86,   86,   86,   86,   84,   86,   83,
        0,   85,   87,   88,   88,   88,   88,    0,    0,   87,

       89,   89,   89,   89,   84,    0,    0,    0,   85,   88,
        0,    0,    0,   86,   90,   90,   90,   90,    0,    0,
        0,   89,    0,   88,    0,    0,    0,   90,    0,    0,
       89,   91,   91,   91,   91,   92,   92,   92,   92,   93,
       93,   93,   93,    0,   90,   94,   94,   94,   94,    0,
        0,    0,   91,   95,   95,   95,   95,   96,   96,   96,
       96,   91,    0,    0,    0,   92,    0,    0,    0,   93,
        0,    0,   93,    0,    0,   94,    0,    0,   92,   97,
       97,   97,   97,   95,   94,    0,    0,   96,   98,   98,
       98,   98,    0,    0,    0,    0,    0,   96,    0,    0,

        0,   95,   99,   99,   99,   99,    0,    0,    0,   97,
      100,  100,  100,  100,  101,  101,  101,  101,   98,    0,
        0,    0,   97,   98,  102,  102,  102,  102,  103,  103,
      103,  103,   99,  104,  104,  104,  104,    0,    0,    0,
      100,   99,    0,    0,  101,  101,    0,    0,    0,  100,
      105,  105,  105,  105,  102,    0,    0,    0,  103,    0,
        0,    0,    0,  104,  106,  106,  106,  106,    0,  103,
        0,    0,  102,  109,  109,  109,  109,    0,    0,  104,
      105,  110,  110,  110,  110,    0,    0,    0,  110,  105,
      111,  111,  111,  111,  106,  112,  112,  112,  112,  113,

      113,  113,  113,  109,    0,  115,  115,  115,  115,  113,
      106,  110,  114,  114,  114,  114,    0,    0,  114,    0,
      111,    0,    0,  111,  115,  112,    0,    0,    0,  113,
      116,  116,  116,  116,    0,  115,    0,    0,  112,    0,
        0,    0,  114,  117,  117,  117,  117,    0,  118,  118,
      118,  118,    0,  116,  119,  119,  119,  119,    0,    0,
      116,  120,  120,  120,  120,  123,  123,  123,  123,  124,
      124,  124,  124,  117,    0,    0,  124,    0,  118,  117,
      118,    0,    0,    0,  119,  125,  125,  125,  125,    0,
        0,  120,    0,    0,    0,  123,    0,    0,  119,  124,

      126,  126,  126,  126,  129,  129,  129,  129,    0,  120,
      130,  130,  130,  130,    0,  125,    0,  130,  125,  131,
      131,  131,  131,  132,  132,  132,  132,    0,    0,    0,
      126,    0,    0,    0,  129,  133,  133,  133,  133,    0,
      130,    0,    0,  126,  134,  134,  134,  134,    0,  131,
        0,    0,  131,  132,    0,    0,    0,  133,    0,  134,
      135,  135,  135,  135,    0,  133,  132,    0,  136,  136,
      136,  136,    0,    0,  134,  137,  137,  137,  137,  138,
      138,  138,  138,  135,  139,  139,  139,  139,    0,    0,
      135,  136,    0,    0,  137,    0,  138,    0,  136,    0,

        0,  139,    0,    0,    0,  137,    0,    0,    0,  138,
      140,  140,  140,  140,  139,  141,  141,  141,  141,  142,
      142,  142,  142,  141,    0,  143,  143,  143,  143,  144,
      144,  144,  144,  140,  143,  145,  145,  145,  145,    0,
      140,    0,  142,    0,    0,  141,    0,    0,    0,  142,
        0,  144,    0,    0,    0,  143,    0,    0,  145,  144,
      146,  146,  146,  146,    0,  145,  147,  147,  147,  147,
        0,    0,    0,  146,  148,  148,  148,  148,  149,  149,
      149,  149,  150,  150,  150,  150,  153,  153,  153,  153,
      146,  151,  151,  151,  151,    0,  147,  152,  152,  152,

      152,  152,    0,    0,  148,    0,    0,    0,  149,    0,
        0,    0,  150,  147,  148,    0,  153,  154,  154,  154,
      154,  151,  155,  155,  155,  155,  149,  152,  153,    0,
      150,  156,  156,  156,  156,  151,  157,  157,  157,  157,
        0,  158,  158,  158,  158,    0,    0,  154,  159,  159,
      159,  159,  155,  160,  160,  160,  160,    0,    0,  154,
        0,  156,    0,    0,    0,  156,  157,    0,    0,    0,
      155,  158,  161,  161,  161,  161,  158,    0,  159,  162,
      162,  162,  162,  160,  157,  163,  163,  163,  163,  164,
      164,  164,  164,  164,  162,  159,  165,  165,  165,  165,

        0,  160,  161,    0,    0,    0,  165,    0,    0,  162,
        0,  161,    0,    0,    0,  163,    0,    0,    0,  164,
      166,  166,  166,  166,    0,  163,  165,  167,  167,  167,
      167,    0,    0,  168,  168,  168,  168,  169,  169,  169,
      169,    0,    0,    0,  166,  170,  170,  170,  170,    0,
      166,  167,  168,  171,  171,  171,  171,  167,    0,  172,
      172,  172,  172,  168,    0,    0,    0,  169,    0,  173,
      173,  173,  173,  169,    0,  170,  174,  174,  174,  174,
        0,    0,    0,  171,  173,  176,  176,  176,  176,  172,
      177,  177,  177,  177,  170,    0,    0,    0,    0,  173,

      176,    0,  171,  172,    0,    0,  174,  175,  175,  175,
      175,  175,    0,    0,    0,  176,  174,    0,    0,    0,
      177,  178,  178,  178,  178,  178,  179,  179,  179,  179,
      177,  180,  180,  180,  180,  179,    0,  175,  181,  181,
      181,  181,    0,    0,  180,  182,  182,  182,  182,    0,
        0,  178,  183,  183,  183,  183,  179,  184,  184,  184,
      184,  180,  185,  185,  185,  185,  182,    0,  181,    0,
      186,  186,  186,  186,    0,  182,  186,  187,  187,  187,
      187,    0,  183,    0,    0,  185,    0,  184,  188,  188,
      188,  188,  185,  192,  192,  192,  192,    0,  187,    0,

      186,  189,  189,  189,  189,    0,  188,  187,  190,  190,
      190,  190,    0,    0,  189,    0,    0,  190,  188,  191,
      191,  191,  191,  192,  193,  193,  193,  193,  192,    0,
        0,  189,  194,  194,  194,  194,  191,    0,  190,  195,
      195,  195,  195,  196,  196,  196,  196,    0,    0,  191,
      197,  197,  197,  197,  193,  198,  198,  198,  198,    0,
        0,    0,  194,  193,  199,  199,  199,  199,    0,  195,
        0,    0,    0,  196,    0,  196,    0,    0,  194,    0,
      197,  200,  200,  200,  200,  198,    0,  195,  201,  201,
      201,  201,    0,    0,  199,    0,  197,    0,  198,  202,

      202,  202,  202,  199,  203,  203,  203,  203,    0,    0,
        0,  200,  202,    0,    0,    0,  200,    0,  201,  204,
      204,  204,  204,    0,  205,  205,  205,  205,  204,  202,
      201,    0,    0,    0,  203,  205,  206,  206,  206,  206,
        0,    0,    0,  203,  207,  207,  207,  207,    0,  204,
      208,  208,  208,  208,  205,    0,    0,    0,    0,  206,
      209,  209,  209,  209,    0,    0,  206,    0,  207,  210,
      210,  210,  210,    0,  207,  211,  211,  211,  211,    0,
      208,  212,  212,  212,  212,  208,  213,  213,  213,  213,
      209,    0,    0,    0,  212,    0,    0,  209,    0,  210,

      214,  214,  214,  214,    0,  211,  215,  215,  215,  215,
        0,  212,    0,  214,    0,    0,  213,  210,  216,  216,
      216,  216,    0,    0,  211,  213,  217,  217,  217,  217,
      214,    0,    0,  217,    0,    0,  215,  218,  218,  218,
      218,  219,  219,  219,  219,  215,    0,    0,  216,    0,
      218,  220,  220,  220,  220,    0,  217,  221,  221,  221,
      221,  222,  222,  222,  222,    0,    0,  218,    0,    0,
      221,  219,    0,    0,    0,  220,  223,  223,  223,  223,
        0,  220,    0,    0,    0,  222,    0,  221,    0,    0,
        0,  222,    0,    0,  223,  224,  224,  224,  224,    0,

        0,  224,  226,  226,  226,  226,  223,  225,  225,  225,
      225,  227,  227,  227,  227,  228,  228,  228,  228,  229,
      229,  229,  229,    0,    0,  224,  230,  230,  230,  230,
      225,    0,  226,    0,    0,  226,    0,  225,    0,    0,
        0,  227,    0,    0,    0,  228,    0,    0,    0,  229,
      227,  231,  231,  231,  231,    0,  230,    0,  229,  232,
      232,  232,  232,    0,  228,  233,  233,  233,  233,  234,
      234,  234,  234,    0,    0,  230,  234,  235,  235,  235,
      235,  231,  236,  236,  236,  236,    0,    0,    0,  232,
        0,  232,    0,    0,  231,  233,    0,    0,    0,  234,

        0,    0,    0,  236,    0,    0,    0,  235,    0,    0,
      235,    0,  236,  233,  237,  237,  237,  237,  238,  238,
      238,  238,  239,  239,  239,  239,  240,  240,  240,  240,
      241,  241,  241,  241,  242,  242,  242,  242,    0,    0,
        0,  242,    0,    0,  237,  239,    0,    0,  238,    0,
        0,    0,  239,    0,    0,    0,  240,    0,    0,    0,
      241,    0,    0,    0,  242,  243,  243,  243,  243,    0,
        0,    0,  240,  244,  244,  244,  244,    0,  241,    0,
      244,  245,  245,  245,  245,  246,  246,  246,  246,  247,
      247,  247,  247,    0,    0,  243,    0,    0,  243,    0,

      247,    0,    0,  244,    0,    0,  248,  248,  248,  248,
        0,  245,    0,    0,  245,  246,  248,    0,    0,  247,
      249,  249,  249,  249,  250,  250,  250,  250,    0,    0,
        0,  249,  251,  251,  251,  251,  248,  252,  252,  252,
      252,  253,  253,  253,  253,    0,    0,  250,    0,  251,
      249,    0,    0,    0,  250,  254,  254,  254,  254,    0,
        0,  252,  251,  255,  255,  255,  255,  252,    0,    0,
        0,  253,  256,  256,  256,  256,  257,  257,  257,  257,
      258,  258,  258,  258,    0,  254,  259,  259,  259,  259,
        0,    0,  254,  255,    0,  260,  260,  260,  260,  255,

        0,    0,  256,    0,    0,    0,  257,    0,    0,  256,
      258,  261,  261,  261,  261,    0,  259,  262,  262,  262,
      262,    0,  258,    0,  257,  260,  263,  263,  263,  263,
        0,    0,    0,  261,    0,  259,  264,  264,  264,  264,
        0,  261,  265,  265,  265,  265,    0,  262,  266,  266,
      266,  266,  267,  267,  267,  267,  263,  268,  268,  268,
      268,    0,    0,    0,  262,    0,  264,  269,  269,  269,
      269,    0,  265,  270,  270,  270,  270,    0,  266,    0,
        0,    0,  267,  270,    0,    0,    0,  268,  271,  271,
      271,  271,  272,  272,  272,  272,    0,  269,  273,  273,

      273,  273,    0,  270,  274,  274,  274,  274,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  271,    0,
        0,    0,  272,    0,  271,    0,    0,    0,  273,    0,
        0,    0,    0,    0,  274,  287,  287,  287,  288,  288,
      288,  289,  289,  289,  290,  290,  290,  292,  292,  294,
      294,  296,  296,  298,  298,  286,  286,  286,  286,  286,
      286,  286,  286,  286,  286,  286,  286,  286,  286,  286,
      286,  286,  286,  286,  286,  286,  286,  286,  286,  286,
      286,  286,  286,  286,  286,  286,  286,  286,  286,  286,
      286,  286,  286,  286,  286,  286,  286,  286,  286,  286,

      286,  286,  286,  286,  286,  286,  286,  286,  286,  286,
      286,  286,  286,  286,  286
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
#line 2 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
// SPDX-License-Identifier: LGPL-2.1-or-later
/*
 * libiio - Library for interfacing industrial I/O (IIO) devices
 *
 * Copyright (C) 2014 Analog Devices, Inc.
 * Author: Paul Cercueil <paul.cercueil@analog.com>
 */

#include "parser.h"
#include "ops.h"

#include <string.h>
#line 1073 "/build/libiio/src/build/iiod/lexer.c"
#define YY_NO_UNISTD_H 1
#define YY_NO_INPUT 1

#line 1077 "/build/libiio/src/build/iiod/lexer.c"

#define INITIAL 0
#define WANT_DEVICE 1
#define WANT_CHN_OR_ATTR 2
#define WANT_CHN 3
#define WANT_ATTR 4
#define WANT_VALUE 5

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

YYSTYPE * yyget_lval ( yyscan_t yyscanner );

void yyset_lval ( YYSTYPE * yylval_param , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 25 "/build/libiio/src/libiio-0.24/iiod/lexer.l"


#line 1357 "/build/libiio/src/build/iiod/lexer.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 287 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 2356 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 27 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	return VERSION;
}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 31 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	return PRINT;
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 35 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	return ZPRINT;
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 39 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	return EXIT;
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 43 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	return HELP;
}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 47 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	return TIMEOUT;
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 51 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	BEGIN(WANT_DEVICE);
	return OPEN;
}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 56 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	BEGIN(WANT_DEVICE);
	return CLOSE;
}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 61 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	BEGIN(WANT_DEVICE);
	return READ;
}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 66 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	BEGIN(WANT_DEVICE);
	return READBUF;
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 71 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	BEGIN(WANT_DEVICE);
	return WRITEBUF;
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 76 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	BEGIN(WANT_DEVICE);
	return WRITE;
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 81 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	BEGIN(WANT_DEVICE);
	return SETTRIG;
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 86 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	BEGIN(WANT_DEVICE);
	return GETTRIG;
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 91 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	BEGIN(WANT_DEVICE);
	return SET;
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 96 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	struct parser_pdata *pdata = yyget_extra(yyscanner);
	struct iio_device *dev = iio_context_find_device(pdata->ctx, yytext);
	yylval->dev = dev;
	pdata->dev = dev;
	BEGIN(WANT_CHN_OR_ATTR);
	return DEVICE;
}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 105 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	BEGIN(WANT_VALUE);
	return BUFFERS_COUNT;
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 110 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	BEGIN(WANT_ATTR);
	return DEBUG_ATTR;
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 115 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	BEGIN(WANT_ATTR);
	return BUFFER_ATTR;
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 120 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	struct parser_pdata *pdata = yyget_extra(yyscanner);
	pdata->channel_is_output = yytext[0] == 'o' || yytext[0] == 'O';
	BEGIN(WANT_CHN);
	return IN_OUT;
}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 127 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	struct parser_pdata *pdata = yyget_extra(yyscanner);
	struct iio_channel *chn = NULL;
	if (pdata->dev)
		chn = iio_device_find_channel(pdata->dev,
					yytext, pdata->channel_is_output);
	yylval->chn = chn;
	pdata->chn = chn;
	BEGIN(WANT_ATTR);
	return CHANNEL;
}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 139 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	char *end;
	char errstr[100];

	errno = 0;
	yylval->value = strtol(yytext, &end, 10);
	if (yytext == end || errno == ERANGE) {
		snprintf(errstr, sizeof(errstr), "lex : bad long constant: %s",(char*)yytext);
		perror(errstr);
	}
	return VALUE;
}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 152 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	return CYCLIC;
}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 156 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	yylval->word = strdup(yytext);
	return WORD;
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 161 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	return SPACE;
}
	YY_BREAK
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
#line 165 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	BEGIN(INITIAL);
	return END;
}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 170 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
{
	BEGIN(INITIAL);
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 173 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
ECHO;
	YY_BREAK
#line 1648 "/build/libiio/src/build/iiod/lexer.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(WANT_DEVICE):
case YY_STATE_EOF(WANT_CHN_OR_ATTR):
case YY_STATE_EOF(WANT_CHN):
case YY_STATE_EOF(WANT_ATTR):
case YY_STATE_EOF(WANT_VALUE):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 287 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 287 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 286);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 173 "/build/libiio/src/libiio-0.24/iiod/lexer.l"
